#include <Adafruit_SSD1306.h>

#define OLED_I2C_ADDRESS 0x3C
#define OLED_WIDTH 128
#define OLED_HEIGHT 64
#define INPUT_PIN A0

Adafruit_SSD1306 oled(OLED_WIDTH, OLED_HEIGHT);

void setup() {
  if (!oled.begin(SSD1306_SWITCHCAPVCC, OLED_I2C_ADDRESS)) {
    while (true);
  }
  oled.clearDisplay();
  showHeader();
  oled.display();
}

void loop() {
  float volt = analogRead(INPUT_PIN) * 5.0 / 1024;
  showValue(String(volt) + "V");
  oled.display();
  delay(100);
}

void showHeader() {
  oled.setTextSize(1);
  oled.setTextColor(WHITE);
  oled.setCursor(4, 4);
  oled.print("Voltmetro");
  oled.setCursor(112, 4);
  oled.print("A0");
  oled.drawLine(0, 15, 128, 15, WHITE);
}

void showValue(String value) {
  oled.fillRect(0, 16, 128, 48, BLACK);
  oled.setTextSize(3);
  oled.setCursor(OLED_WIDTH / 2, OLED_HEIGHT / 2 + 8);
  printCenteredText(value);
}

void printCenteredText(String text) {
  int16_t x = 0, y = 0;
  uint16_t w = 0, h = 0;
  int16_t cursorX = oled.getCursorX();
  int16_t cursorY = oled.getCursorY();
  oled.getTextBounds(text, 0, 0, &x, &y, &w, &h);
  oled.setCursor(cursorX - x - w / 2, cursorY - y - h / 2);
  oled.print(text);
}